#
# spec file for package bladeRF
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2015 Wojciech Kazubski, wk@ire.pw.edu.pl
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
%define libname lib%{name}%{sover}
%define libversion 2.0.2
%define release_name 2018.08
%define bladerf_group bladerf
%define use_syslog 0
Name:           bladeRF
Version:        1.4.0
Release:        6.1
Summary:        SDR radio receiver
License:        GPL-2.0-only AND AGPL-3.0-or-later
Group:          Productivity/Hamradio/Other
URL:            http://nuand.com/
#Git-Clone:     https://github.com/Nuand/bladeRF.git
Source:         https://github.com/Nuand/bladeRF/archive/%{release_name}.tar.gz#/%{name}-%{release_name}.tar.xz
BuildRequires:  cmake >= 2.8.4
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  tecla-devel
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
The software for bladeRF USB 3.0 Superspeed Software Defined Radio.

%package -n %{libname}
Version:        %{libversion}
Release:        6.1
Summary:        Library for bladeRF
Group:          System/Libraries
Requires:       %{name}-udev

%description -n %{libname}
Library for bladeRF, SDR transceiver.

%package udev
Summary:        Udev rules for bladeRF
Group:          Hardware/Other
Requires(pre):  shadow

%description udev
Udev rules for bladeRF

%package devel
Summary:        Development files for libbladeRF
Group:          Development/Libraries/Other
Requires:       %{libname} = %{libversion}

%description devel
Libraries and header files for developing applications that want to make
use of libbladerf.

%prep
%setup -q -n %{name}-%{release_name}

%build
cd host
%cmake \
  -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
  -DUDEV_RULES_PATH=%{_udevrulesdir} \
  -DBLADERF_GROUP=%{bladerf_group} \
  -DBUILD_DOCUMENTATION=YES \
%if 0%{?use_syslog}
  -DENABLE_LIBBLADERF_SYSLOG=ON \
%endif
  -DBUILD_DOCUMENTATION=ON
%make_jobs

%install
cd host
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun  -n %{libname} -p /sbin/ldconfig

%pre udev
getent group %{bladerf_group} >/dev/null || groupadd -r %{bladerf_group}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%license COPYING
%doc README.md CONTRIBUTORS
%{_bindir}/bladeRF-cli
%{_bindir}/bladeRF-fsk
%{_mandir}/man1/bladeRF-cli.1%{?ext_man}

%files udev
%{_udevrulesdir}/88-nuand.rules

%files -n %{libname}
%{_libdir}/libbladeRF.so.*

%files devel
%{_libdir}/libbladeRF.so
%{_includedir}/bladeRF1.h
%{_includedir}/bladeRF2.h
%{_includedir}/libbladeRF.h
%{_libdir}/pkgconfig/libbladeRF.pc

%changelog
* Fri Sep  7 2018 Martin Pluskal <mpluskal@suse.com>
- Clarify license status
* Wed Sep  5 2018 mardnh@gmx.de
- Update to version 2018.08
  libbladeRF
  * Added support for Automatic Gain Control
  * Added bladeRF.conf config option file
  * Refactor to support for multiple product lines
  * Add support for the bladeRF Micro product
  * API: replace bladerf_module with bladerf_channel, a reverse-compatible
  * change to handle products with multiple independent RF paths in the same
  * direction
  * API: BREAKING CHANGE - on bladerf_set_frequency, et al, the frequency
  * parameter is now uint64_t instead of unsigned int
  * Add typedefs for common param types, e.g. bladerf_frequency -> uint64_t
  bladeRF-cli
  * Added support for Automatic Gain Control
  * No longer initializes the bladeRF before loading a new FPGA image, to
  * avoid potential catch-22 problems
  * bladeRF 2.0 Micro support
  * Support for MIMO RX and TX using "channel=" parameter on rx/tx config
  * Various code quality fixups
- Remove patches: (fixed upstream)
  * bladeRF-add-cflag-Wno-format-truncation.patch
  * bladeRF-cmake_syntax.patch
* Tue Sep  5 2017 mpluskal@suse.com
- Fix cmake syntax error:
  * bladeRF-cmake_syntax.patch
* Thu Jun  1 2017 mardnh@gmx.de
- Add patch:
  * bladeRF-add-cflag-Wno-format-truncation.patch (boo#1041192)
* Wed Apr 26 2017 mardnh@gmx.de
- build with support for libtecla
* Sun Apr 23 2017 mardnh@gmx.de
- Update group handling
* Thu Apr 20 2017 mpluskal@suse.com
- Update group handling
* Sat Apr 15 2017 mardnh@gmx.de
- Workaround for generating manpages/documentation on
  systems emulated via qemu (arm, ppc,...) not longer needed
* Sat Apr 15 2017 mardnh@gmx.de
- Adjust Source-URL
- Use proper cmake options
- Use group bladerf in the udev-rules
* Thu Mar 30 2017 wk@ire.pw.edu.pl
- fixed libbladeRF version to 1.7.2
* Thu Mar 23 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- RPM group fix.
* Thu Mar  9 2017 mpluskal@suse.com
- Update to version 1.4.0
- Cleanup spec file with spec-cleaner
* Fri Feb 19 2016 dl8fcl@t-online.de
- udev_rules_update added for openSUSE
* Sat Aug  1 2015 wk@ire.pw.edu.pl
- updated to release 2015.07
- libbladeRF version 1.4.3
- bladeRF-cli version 1.2.1
* Tue Mar  3 2015 wk@ire.pw.edu.pl
- fixed build on armv7l (openSUSE 13.2)
* Sun Mar  1 2015 wk@ire.pw.edu.pl
- updated to release 2015.02
- libbladeRF version 1.2.1
- bladeRF-cli version 1.1.2
* Sun Aug  3 2014 wk@ire.pw.edu.pl
- updated to git 20140803
* Fri Jul 25 2014 wk@ire.pw.edu.pl
- version 0.16.2 git20140725
* Sun Oct  6 2013 Wojciech Kazubski <wk@ire.pw.edu.pl> - 0.0.20130915-1.1
- git 20130915
- initial spec file.
